pub struct RegionClassificationCode(_);
This structure encapsulates the integer code for regions defined in the UN M49 standard.

Implementations

Returns the M49 code as an integer.

Return the M49 defined name for this region. Note that where the region this name may not be the same as the short_name defined in the ISO 3166 CountryCode.

Return the kind, or level, of this region.

Return the RegionClassificationCode instance for the parent of this region if one is specified.

If this region is a country (kind is RegionKind::Country) return the ISO 3166 CountryCode corresponding to this region. Note that if the feature country_codes is not specified this function will return &str.